@@ -19,11 +19,11 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-Version 2.3
+Version 2.4
 
 =cut
 
-our $VERSION = '2.3';
+our $VERSION = '2.4';
 
 =head1 SYNOPSIS
 
@@ -118,17 +118,17 @@ sub conjunction {
 	return join(" $punct{$list_type} ", @list) if(scalar(@list) == 2);
 
 	if ( $punct{pen} ) {
-		return join "$punct{sep} ", @list[ 0 .. $#_ - 1 ],
-		  "$punct{$list_type} $_[-1]",
+		return join "$punct{sep} ", @list[ 0 .. $#list - 1 ],
+		  "$punct{$list_type} $list[-1]",
 		  unless grep /$punct{sep}/, @list;
-		return join "$punct{alt} ", @list[ 0 .. $#_ - 1 ],
-		  "$punct{$list_type} $_[-1]";
+		return join "$punct{alt} ", @list[ 0 .. $#list - 1 ],
+		  "$punct{$list_type} $list[-1]";
 	} else {
-		return join "$punct{sep} ", @list[ 0 .. $#_ - 2 ],
-		  "$_[-2] $punct{$list_type} $_[-1]",
+		return join "$punct{sep} ", @list[ 0 .. $#list - 2 ],
+		  "$list[-2] $punct{$list_type} $list[-1]",
 		  unless grep /$punct{sep}/, @list;
-		return join "$punct{alt} ", @list[ 0 .. $#_ - 2 ],
-		  "$_[-2] $punct{$list_type} $_[-1]";
+		return join "$punct{alt} ", @list[ 0 .. $#list - 2 ],
+		  "$list[-2] $punct{$list_type} $list[-1]";
 	}
 }
 
@@ -141,7 +141,7 @@ Sets the separator, usually ',' or ';'.
 =cut
 
 sub separator {
-    $punct{sep} = $_[1];
+	$punct{sep} = $_[1];
 }
 
 =head2 separator_phrase
@@ -164,9 +164,9 @@ sub separator_phrase {
 
 =head2 penultimate
 
-Enables/disables punultimate separator.
+Enables/disables penultimate separator.
 
-You may use the C<penultimate> routine to diable the separator after the
+You may use the C<penultimate> routine to disable the separator after the
 next to last item.
 In English, The Oxford Comma is a highly debated issue.
 
@@ -293,7 +293,7 @@ Nigel Horne C<< <njh at bandsman.co.uk> >>
 
 C<Locale::Language>, C<List::ToHumanString>
 
-The I<Perl Cookbook> in Section 4.2 has a simular subroutine called
+The I<Perl Cookbook> in Section 4.2 has a similar subroutine called
 C<commify_series>. The differences are that
 1. this routine handles multiple languages and
 2. being a module, you do not have to add the subroutine to a script every time you need it.
